/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: SLSBPUnitRefMethodInjection00.java 1970 2007-10-16 11:49:25Z benoitf $
 * --------------------------------------------------------------------------
 */
package org.ow2.easybeans.tests.common.ejbs.stateless.containermanaged.persistenceunitref;

import static org.ow2.easybeans.tests.common.helper.ContextHelper.checkEntityManagerFactory;

import javax.annotation.Resource;
import javax.ejb.Remote;
import javax.ejb.SessionContext;
import javax.ejb.Stateless;
import javax.persistence.EntityManagerFactory;
import javax.persistence.PersistenceUnit;

import org.ow2.easybeans.tests.common.ejbs.base.ItfCheck00;

/**
 * This bean is used to test the &#64;PersistenceUnit annotation on methods.
 * @author Eduardo Studzinski Estima de Castro
 * @author Gisele Pinheiro Souza
 */
@Stateless(name = "SLSBPUnitRefMethodInjection00")
@Remote(ItfCheck00.class)
public class SLSBPUnitRefMethodInjection00 implements ItfCheck00{

    /**
     * SessionContext.
     */
    @Resource
    private SessionContext sessionContext;

    /**
     * The reference must be injected by the container.
     */
    private EntityManagerFactory emf00;

    /**
     * The reference must be injected by the container.
     */
    private EntityManagerFactory emf01;

    /**
     * Method injection. Container must create the default name.
     */
    private EntityManagerFactory emf02;

    /**
     * Method injection.
     * @param emf entity manager factory reference
     */
    @PersistenceUnit(name = "persistence/pu00")
    public void setPersistenceUnit00(final EntityManagerFactory emf) {
        emf00 = emf;
    }

    /**
     * Method injection.
     * @param emf entity manager factory reference
     */
    @PersistenceUnit(name = "persistence/pu01", unitName = "testEntity00")
    public void setPersistenceUnit01(final EntityManagerFactory emf) {
        emf01 = emf;
    }

    /**
     * Method injection.
     * @param emf entity manager factory reference
     */
    @PersistenceUnit(unitName = "testEntity00")
    public void setEmf02(final EntityManagerFactory emf) {
        emf02 = emf;
    }

    /**
     * Checks if the injection using &#64;PersistenceUnit is working properly on bean methods.
     * The cotainer must:
     * <li>inject only defined name, the unit name is not used because there is only a persistent unit declared;</li>
     * <li>inject with defined name and unit name;</li>
     * <li>inject without defined name, the default name must be defined by the container.</li>
     */
    public void check() {
        checkEntityManagerFactory(sessionContext, emf00, "persistence/pu00");
        checkEntityManagerFactory(sessionContext, emf01, "persistence/pu01");
        checkEntityManagerFactory(sessionContext, emf02,
                "org.ow2.easybeans.tests.common.ejbs.stateless.containermanaged."
                + "persistenceunitref.SLSBPUnitRefMethodInjection00/emf02");
    }
}
